
from pathlib import Path
import numpy as np
import matplotlib.pyplot as plt
from MDAnalysis import Universe
from MDAnalysis.lib.distances import distance_array, calc_angles, calc_bonds, minimize_vectors
from ase.io import read


# PT donor group
idxs_type1_o = [150]

# PT acceptor group
idxs_type2_o = [130, 241, 136, 139, 129]

# adsorption sites, please only use one site at a time
ad_site = [62]

for j in range(4):
    wkdir = Path(f"/capstor/store/cscs/userlab/lp07/zyongbin/BiVO4FEP/05.metad/opes_new/opes_pot{j}/bak_traj")
    all_info = []

    for i in range(6):
        #lammpstrj = "clip.lammpstrj"
        lammpstrj = wkdir/f"{(i*5):02d}-{((i+1)*5):02d}ns.dump.lammpstrj"
        print("Processing", lammpstrj, flush=True)
        stc = read(lammpstrj, format="lammps-dump-text", specorder=["Bi", "H", "O", "V"])
        chemical_symbols = stc.get_chemical_symbols()
        u= Universe(lammpstrj, format="LAMMPSDUMP")
        u.add_TopologyAttr("types", np.array(chemical_symbols))
        for ts in u.trajectory:
            # for each frame
            print(f"frame {ts.frame}")
            # initialize the cv array
            # [frame, cv1, cv2, n_hbonds] 
            info = np.zeros((2))
            
            # get the positions
            poses_donor_o = u.atoms.positions[idxs_type1_o[0]]
            poses_bonded_Bi = u.atoms.positions[ad_site[0]]
            # # compute oh_angle with respect to z axis
            BiO_vec = poses_donor_o - poses_bonded_Bi
            BiO_vec = minimize_vectors(BiO_vec, u.dimensions)
            norm_BiO = np.linalg.norm(BiO_vec)

            info[0] = ts.frame
            info[1] = norm_BiO
        
            all_info.append(info)
            print(info)

    all_info = np.array(all_info)
    np.save(f"len_BiOad-xy-mlp{j}.npy", all_info, allow_pickle=False)
